@@ -23,6 +23,13 @@ import gettext
 
 from otopi import util
 
+try:
+    import pwquality
+    _use_pwquality = True
+except ImportError:
+    # do not force this optional feature
+    _use_pwquality = False
+
 
 def _(m):
     return gettext.dgettext(message=m, domain='ovirt-setup-lib')
@@ -63,6 +70,7 @@ def queryEnvKey(
     default=None,
     name=None,
     store=True,
+    max_attemps=1000,
 ):
     """Query string and validate it.
     Params:
@@ -92,11 +100,12 @@ def queryEnvKey(
     )
     interactive = key not in env or env[key] is None
     valid = False
-    while not valid:
+    attemps = 0
+    while not valid and attemps < max_attemps:
         if interactive:
             value = dialog.queryString(
                 name=(
-                    'queryEnvKey_input:{key}'.format(key=key)
+                    'queryEnvKey_input_{key}'.format(key=key)
                     if name is None
                     else name
                 ),
@@ -119,13 +128,14 @@ def queryEnvKey(
                     if test.get('is_error', True):
                         logger.error(msg)
                         valid = False
+                        attemps += 1
                         break
                     else:
                         logger.warning(msg)
                         if not queryBoolean(
                             dialog=dialog,
                             name=(
-                                'queryEnvKey_warnverify:{key}'.format(
+                                'queryEnvKey_warnverify_{key}'.format(
                                     key=key
                                 ) if test.get('warn_name') is None
                                 else test['warn_name']
@@ -137,6 +147,7 @@ def queryEnvKey(
                             default=False,
                         ):
                             valid = False
+                            attemps += 1
                             break
                 else:  # Not interactive
                     if test.get('is_error', True):
@@ -144,6 +155,8 @@ def queryEnvKey(
                         raise RuntimeError(msg)
                     else:
                         logger.warning(msg)
+    if attemps == max_attemps:
+        raise RuntimeError('Maximum retry count has been reached')
     if store:
         env[key] = value
     return value
@@ -177,25 +190,22 @@ def queryPassword(
         note_verify_same - prompt to be displayed when querying again
         error_msg_not_same - error message to be displayed if not same
         verify_hard - optionally check that it is hard enough,
-            if cracklib is installed
+            if pwquality is installed
         warn_not_hard - warning to be displayed if not hard enough
             if string includes '{error}', it will be replaced by
-            actual error returned from cracklib
+            actual error returned from pwquality
         tests - extra tests to run, in the format of queryEnvKey
     """
 
     def password_hard_enough(password):
         res = ''
         try:
-            import cracklib
-            cracklib.FascistCheck(password)
-        except ImportError:
-            logger.debug(
-                'cannot import cracklib',
-                exc_info=True,
-            )
-        except ValueError as error:
-            res = warn_not_hard.format(error=error)
+            if(_use_pwquality):
+                pwq = pwquality.PWQSettings()
+                pwq.read_config()
+                pwq.check(password, None, None)
+        except pwquality.PWQError as e:
+            res = warn_not_hard.format(error=e.args[1])
         return res
 
     if not note_verify_same:
